#!/bin/bash
#
# July 29, 2002
#
get_file_size()
{
    set $(ls -Ls $1)
#    echo "${1%%"k"}KB"
    echo "$(( ($1)/2 ))KB"
}

WEBPAGE="../current/ePiX.html"

source ePiX.config

## Begin HERE document ##
cat <<CHUNK > $WEBPAGE
<html>
<head>
<title>ePiX Home Page</title>
<META name="description" content="A LaTeX pre-processor for creating
camera-quality mathematically accurate figures.">
<META name="keywords" content="accurate camera eepic ePiX figures free
fsf gnu gnuplot gpl graphing LaTeX mathematical mathematically picture
plot plots plotting quality software 2-D typography utility">
</head>

<body bgcolor="ffffff">


<h3>The <tt>ePiX</tt> Home Page</h3>

Last change: $(date +%d) $(date +%B), $(date +%Y)
<p>

Latest stable is $V_STABLE, latest beta is $V_BETA -- 
<a href="../software/CHANGELOG"><b>CHANGELOG</b></a>,
<a href="../software/INSTALL"><b>INSTALL</b></a>,
<a href="../software/README"><b>README</b></a> 
<p>

<a href="../software/images/index.html"><b>Screenshots</b></a> (png
files, not print quality)
<p>

<a href="#News">News</a> (for users who are upgrading)
<p>

<a href="#Overview">Overview</a> (for new users)
<p>

<a href="#Downloading">Downloads</a><br>
<a href="#Source">Source Packages</a><br>

<a href="#RPM">RPM Package</a> for Version $V_RPM
<p>

<a href="#Docs">User's Guide and Tutorial</a> for Version $V_DOC
<br>
<a href="#Other">Sample Document</a> for Version $V_SAMPLE
<p>

<a href="#Req">Software Requirements</a>
<br>
<a href="#Inst">Installation</a>
<br>
<a href="#Lic">License</a>
<p>

<hr>

CHUNK
cat NEWS.html >> $WEBPAGE

cat <<CHUNK >> $WEBPAGE

<h2><a name="Overview">Overview</a></h2>

If you need to produce high-quality, mathematically accurate
2-dimensional plots and figures for inclusion in <tt>LaTeX</tt>
documents, but are seeking a fast, lightweight, Free utility whose
output matches the appearance of <tt>LaTeX</tt>, then you may be
interested in <tt>ePiX</tt>. 
<p>

To the user, <tt>ePiX</tt> is much like <tt>LaTeX</tt>: You prepare an
input file having a certain simple format and containing mnemonic
commands to generate plot objects, then \`compile' the file to obtain
an <tt>.eepic</tt> file that can be included in a <tt>LaTeX</tt>
document. For more details, please see the online
<a href="../software/epix_html/index.html"><b>tutorial</b></a> (HTML). 
<p>

<tt>ePiX</tt> supports several graphics primitives (lines, triangles,
coordinate rectangles, arrows, circular arcs, general ellipses and
half-ellipses, quadratic and cubic splines) as well as Cartesian,
polar, and parametric plots of user-defined functions, and much
more. Because an <tt>ePiX</tt> file is a C++ program, with
<tt>ePiX</tt> you can exploit the full power of C++ in drawing
figures. However, you need only the rudiments of C++ (which are amply
provided in the documentation) in order to use <tt>ePiX</tt>.  <p>

<tt>ePiX</tt> uses the <tt>epic</tt> and <tt>eepic</tt> styles, which
enhance the <tt>LaTeX</tt> picture environment, but has features that
make it both more powerful and easier to use than the picture
environment. <tt>ePiX</tt> allows you to design and draw figures in
Cartesian coordinates (without direct reference to <tt>LaTeX</tt>'s 
current unitlength or the dimensions of the eventual figure), and
easily to control the aspect ratio of figures. Your picture is
automatically sized and placed where it belongs, in the box where
<tt>LaTeX</tt> thinks it is, not on top of the surrounding text.
<p>

<hr>

<h2><a name="Downloading">Downloading</a> <tt>ePiX</tt></h2>

<h1><a name="Source">Source Code Packages</a></h1> 

Supported <tt>ePiX</tt> versions are 
<dd> <a href="../software/epix_src.tar.gz"><b>$V_STABLE</b></a>
(latest source-only package; gzip-ed, $(get_file_size epix_src.tar.gz). See below for RPM)
<dd> <a href="../software/epix_complete.tar.gz"><b>${V_STABLE}_complete</b></a>
(includes the tutorial -- see below -- not just the sample files; gzip-ed, $(get_file_size epix_complete.tar.gz))
<dd> <a href="../software/epix_beta.tar.gz"><b>${V_BETA}_complete</b></a>
(latest beta -- feedback greatly appreciated; gzip-ed, $(get_file_size epix_beta.tar.gz))
<dd> <a href="../software/epix-0.6.11.tar.gz"><b>0.6.11</b></a> (final
<tt>C</tt> version, fully backward-compatible; gzip-ed, $(get_file_size epix-0.6.11.tar.gz))
<dd> <a href="../software/checksums">md5 checksums</a><br> 
Please report problems compiling, testing, or installing. See the 
<a href="../software/INSTALL"><b>INSTALL</b></a> for detailed instructions
and further information. If you started using <tt>ePiX</tt> in Version
0.6.5 or later, you may safely download the latest version.
<p>

<h1>(No) Binary Packages</h1>

Due to the nature of the program, there is no point in providing
binary packages. If you don't have a C++ compiler, you can't run
<tt>ePiX</tt>.

<h1><a name="RPM">RPMs</a></h1>

For users of RPM 4.x, there is a
<a href="../software/epix_complete.rpm"><b>complete</b></a> RPM for
Version $V_RPM that was kindly provided by Guido Gonzato, and built
using this <a href="../software/epix.spec"><b>spec file</b></a>. Please 
note that the author does not have access to a machine running RPM 4.x.  
<p>

<hr>

<h1><a name="Docs">Online and Printable Documentation</a></h1>

The latest documentation (not always up to date, but no older than the
links below) is distributed with the
<a href="../software/epix_complete.tar.gz"><b>complete</b></a> package.
<br>

Documentation is available in several forms: You can
read it <a href="../software/epix_html/index.html"><b>online</b></a>
(HTML), or download it as
<dd> <a href="../software/epix_howto.ps.gz"><b>PostScript</b></a>
(gzip-ed, $(get_file_size epix_howto.ps.gz))<br>
<dd> <a href="../software/epix_howto.pdf.gz"><b>PDF</b></a>
(gzip-ed, $(get_file_size epix_howto.pdf.gz))<br>
<dd> <a href="../software/epix_howto.pdf"><b>PDF</b></a>
($(get_file_size epix_howto.pdf))<br>
<dd> <a href="../software/epix_tex.tar.gz"><b>LaTeX source</b></a>
(<tt>LaTeX</tt> and <tt>ePiX</tt> files, gzip-ed tarball,
$(get_file_size epix_tex.tar.gz))<br>
<dd> <a href="../software/epix_html.tar.gz"><b>HTML</b></a>
(gzip-ed tarball, $(get_file_size epix_html.tar.gz), unpacks to online 
version).

<p>The HTML contains transparent png files, which do not display well
in many browsers. The index is also a bit mangled...old version of
LaTeX2HTML? The other formats are camera quality. 
<p>

<h2><a name="Other">Other Documentation</a></h2>

A sample document (distributed with the source code) is available as
<a href="../software/epix_sample.pdf.gz"><b>compressed PDF</b></a>
(gzip-ed, $(get_file_size epix_sample.pdf.gz)) or
<a href="../software/epix_sample.pdf"><b>uncompressed PDF</b></a>
($(get_file_size epix_sample.pdf)).
<p>

There is a semi-technical <a
href="../software/epix_intro.pdf"><b>whitepaper</b></a> (uncompressed
PDF, 153KB) <p>

<hr>

<h2><a name="Req">System Requirements</a></h2>

<a href="http://www.gnu.org/software/software.html"><b>GNU
software</b></a> can be downloaded at no cost. If you are missing any
components listed here, speak to your sysadmin, or start at the link
above.

<ul>
<li> A <tt>C++</tt> compiler, such as <tt>g++</tt>, is essential for
<I>running</I> <tt>ePiX</tt>.

<li> The GNU shell <tt>bash</tt> must be available on your system, or
you must be able to program in your shell. Like <tt>LaTeX</tt>,
<tt>ePiX</tt> is command-line driven, not a GUI program.

<li> If you are on mathcs (and possibly elsewhere), you may need to 
edit your shell configuration file (e.g., <tt>.cshrc</tt> or
<tt>.bashrc</tt>) before you can use <tt>ePiX</tt>; see the
<a href="../software/POST-INSTALL"><b>instructions</b></a>. 

<li> A previewer, such as <tt>xdvi</tt> or <tt>gv</tt>, is very
desirable. 
</ul>

<h2><a name="Inst">Installation</a></h2>

The <a href="../software/INSTALL"><b>INSTALL</b></a> file contains
instructions for downloading, unpacking, and installing. If you have
installed <tt>ePiX</tt> in your <tt>HOME</tt> directory and do not
know if <tt>~/bin</tt> is in your <tt>PATH</tt> (or do not know what
this phrase means:), please read the 
<a href="../software/POST-INSTALL"><b>post-install</b></a>
instructions. 
<p>
On the author's test system the installation procedure is <p>
<dd><tt>% make test; make contrib; make install</tt>
<p>

<h2><a name="Lic">License</a></h2>

<tt>ePiX</tt> is <a href="http://www.fsf.org/philosophy/free-sw.html">
<b>Free Software</b></a>, distributed under the GNU 
<a href="http://www.fsf.org/copyleft/gpl.html"><b>GPL</b></a>. This
license grants you four specific Freedoms:
<p>

<ul>
  <li>To run <tt>ePiX</tt>, for any purpose (freedom 0).
  <li>To study how <tt>ePiX</tt> works, and adapt it to your needs
  (freedom 1). 
  <li>To redistribute copies of <tt>ePiX</tt> (freedom 2).
  <li>To improve <tt>ePiX</tt>, and release your improvements
     to the public, so that the whole community benefits (freedom 3).
</ul>

<p>

Like all information (including software), <tt>ePiX</tt> comes with
<b>ABSOLUTELY NO WARRANTY, including (but not limited to) any warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE</b>.
<p>

The author believes <tt>ePiX</tt> to be a useful program that produces
mathematically accurate, camera-quality output. If you have questions,
bugs to report, or requests for features, please send the author 
<a href="mailto:ahwang@mathcs.holycross.edu"><b>email</b></a>.
<p>

<p>

<tt>ePiX</tt> is written and maintained by <br>
<dd> Andrew D. Hwang
<dd> Department of Mathematics and Computer Science 
<dd> College of the Holy Cross
<dd> Worcester, MA, 01610-2395, USA
<dd> <tt>ahwang@mathcs.holycross.edu</tt>
<p>

</body>

</html>
CHUNK

chmod 644 $WEBPAGE

exit 0
